## ----setup, include = FALSE---------------------------------------------------
knitr::opts_chunk$set(
    collapse = TRUE,
    comment = "#>",
    crop = NULL, ## Related to https://stat.ethz.ch/pipermail/bioc-devel/2020-April/016656.html
    warning = FALSE
)

## ----'install', eval = FALSE--------------------------------------------------
#  if (!requireNamespace("BiocManager", quietly = TRUE)) {
#      install.packages("BiocManager")
#  }
#  
#  BiocManager::install("CTCF")

## ----get-data-----------------------------------------------------------------
suppressMessages(library(AnnotationHub))
ah <- AnnotationHub()
query_data <- query(ah, "CTCF")
query_data

## -----------------------------------------------------------------------------
query_data["AH95566"]

## -----------------------------------------------------------------------------
CTCF_hg38 <- query_data[["AH95566"]]
CTCF_hg38

## ----echo=FALSE---------------------------------------------------------------
knitr::include_graphics("../man/figures/CTCF_hg38_qvalue.png")

## -----------------------------------------------------------------------------
# Check length before filtering
length(CTCF_hg38)
# Filter and check length after filtering
CTCF_hg38 <- CTCF_hg38[CTCF_hg38$q.value < 0.3]
length(CTCF_hg38)

## ----eval = FALSE-------------------------------------------------------------
#  # hg19 CTCF coordinates
#  CTCF_hg19 <- query_data[["AH95565"]]
#  # mm9 CTCF coordinates
#  CTCF_mm9 <- query_data[["AH95567"]]
#  # mm10 CTCF coordinates
#  CTCF_mm10 <- query_data[["AH95568"]]

## ----'citation', eval = requireNamespace('CTCF')------------------------------
print(citation("CTCF"), bibtex = TRUE)

## ----reproduce1, echo=FALSE---------------------------------------------------
## Date the vignette was generated
Sys.time()

## ----reproduce3, echo=FALSE-------------------------------------------------------------------------------------------
## Session info
library("sessioninfo")
options(width = 120)
session_info()

